@@ -6,10 +6,12 @@ VALIDATE_ERROR_MSG_TEMPLATE = "parameters type should be [{}]"
 STONEWAVE_HOME = os.environ.get("STONEWAVE_HOME", "/tmp")
 USER_DEFINED_TABLE_FUNCTIONS_MODULE = "py_udtfs"
 USER_DEFINED_TABLE_FUNCTIONS_PATH = os.path.join(STONEWAVE_HOME, "var", USER_DEFINED_TABLE_FUNCTIONS_MODULE)
+USER_DEFINED_TABLE_FUNCTION_INFO_FILE = "info.toml"
+SIGNATURE_LIST = "signature_list"
+
 # for ci tests
 if not os.path.exists(USER_DEFINED_TABLE_FUNCTIONS_PATH):
     os.makedirs(USER_DEFINED_TABLE_FUNCTIONS_PATH)
-USER_DEFINED_TABLE_FUNCTION_INFO_FILE = "infos.toml"
 
 
 class ParameterType:
