@@ -1,4 +1,5 @@
 import pyarrow as pa
+from stonewave.sql.udtfs.constants import ParameterDataType as pdt
 
 
 def get_arrow_data_type_from_value(value):
@@ -16,3 +17,16 @@ def get_arrow_data_type_from_value(value):
         # return pa.decimal128(13)
         else:
             return pa.utf8()
+
+
+def get_arrow_data_type(type):
+    if type == pdt.STRING:
+        return pa.utf8()
+    elif type == pdt.FLOAT:
+        return pa.float64()
+    elif type == pdt.INT:
+        return pa.int64()
+    elif type == pdt.BOOL:
+        return pa.bool_()
+    else:
+        return pa.utf8()
